Latex functions
===============

As a big goal of DMT is pretty printing of reports and publications `LaTeX <https://www.latex-project.org/>`__ can be directly used from :ref:`DMT.core.plot<plot>` and also for reports written using :ref:`PyLaTeX<pylatex>`.

The functions to directly interact with LaTeX are:

.. automodule:: DMT.external.latex
    :members:
    :undoc-members:
    :show-inheritance: